<?php

namespace Ems\portalGestor\Controller;

use Ems\portalGestor\Service\EstruturaService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class EstruturaController {

    public function __construct(
        EstruturaService $estruturaService
    ) {
        $this->estruturaService = $estruturaService;
    }

    public function getEstruturasGerenciais(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $cdOperador = (string) $row['CDOPERADOR'];

            $estruturas = $this->estruturaService->
                getEstruturasGerenciais($nrOrg, $cdOperador);

            $response->addDataSet(new DataSet('data', $estruturas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getEstrutura(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $nmTipoEstrutura = $row['NMTIPOESTRUTURA'] ?? null;

            $estruturas = $this->estruturaService->
                getEstrutura($nrOrg, $nmTipoEstrutura);

            $response->addDataSet(new DataSet('data', $estruturas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getAniversariantesEstrutura(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $nrEstrutura = (int) $row['NRESTRUTURAM'];

            $aniversariantes = $this->estruturaService->getAniversariantesEstrutura($nrOrg, $nrEstrutura);

            $response->addDataSet(new DataSet('data', $aniversariantes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
